LAsyncScope class

An asynchronous version of LScope.

Initializes the scope using an asynchronous dependencyFactory and only renders child when initialization completes.

// Example usage:

LAsyncScope(
  dependencyFactory: (scope) async {
    scope.lazyPutAsync(() => DataService.init());
    await scope.findAsync<DataService>();
  },
  loading: (context) => const LoadingSpinner(),
  child: const DataPage(),
)
Inheritance

Constructors

LAsyncScope({Key? key, required LAsyncScopeDependencyFactory dependencyFactory, required Widget child, String? name, Widget loading(BuildContext context)?, Widget error(BuildContext context, Object error)?, List<Object?>? args})
const

Properties

args List<Object?>?
Optional dependency keys for reactive re-initialization.
final
child Widget
The widget subtree to render after initialization.
final
dependencyFactory LAsyncScopeDependencyFactory
An async factory to register dependencies. The child will not render until this Future completes.
final
error Widget Function(BuildContext context, Object error)?
Optional builder for the error state.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading Widget Function(BuildContext context)?
Optional builder for the loading state.
final
name String?
A descriptive name for the scope.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LAsyncScope>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited