dependencyFactory property
An async factory to register dependencies. The child will not render until this Future completes.
Implementation
final LAsyncScopeDependencyFactory dependencyFactory;
An async factory to register dependencies. The child will not render until this Future completes.
final LAsyncScopeDependencyFactory dependencyFactory;