args property
Optional dependency keys for reactive re-initialization.
The bound ModalRoute is always appended internally so the scope resets when route identity changes.
Implementation
final List<Object?>? args;
Optional dependency keys for reactive re-initialization.
The bound ModalRoute is always appended internally so the scope resets when route identity changes.
final List<Object?>? args;