dependencyFactory property
An optional factory to register dependencies in this scope.
Implementation
final LScopeDependencyFactory? dependencyFactory;
An optional factory to register dependencies in this scope.
final LScopeDependencyFactory? dependencyFactory;