LStatusBuilder<T> class

A widget specialized for handling LxStatus.

Eliminates boilerplate when handling loading, error, and success states of an asynchronous reactive value.

// Example usage:

LStatusBuilder(
  userStatus,
  onSuccess: (user) => UserProfile(user),
  onWaiting: () => const LoadingSpinner(),
  onError: (e, s) => ErrorView(e),
);
Inheritance

Constructors

LStatusBuilder(LxReactive<LxStatus<T>> x, {Key? key, required Widget onSuccess(T data), Widget onWaiting()?, Widget onError(Object error, StackTrace? stackTrace)?, Widget onIdle()?})
Creates a status-aware builder.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError Widget Function(Object error, StackTrace? stackTrace)?
Called when the status is LxError.
final
onIdle Widget Function()?
Called when the status is LxIdle.
final
onSuccess Widget Function(T data)
Called when the status is LxSuccess.
final
onWaiting Widget Function()?
Called when simple waiting logic is needed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x LxReactive<LxStatus<T>>
The reactive status to observe.
final

Methods

createElement() Element
Inflates this configuration to a concrete instance.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited