autoWatch property

bool autoWatch
final

Whether to wrap buildView / builder in an LWatch.

Defaults to true. When true, read reactives directly in the build method; do not wrap the whole tree in another LWatch.

Implementation

final bool autoWatch;