buildView method

  1. @protected
Widget buildView(
  1. BuildContext context,
  2. T controller
)

Builds the view content for the given controller.

Subclasses can override this instead of providing a builder.

Implementation

@protected
Widget buildView(
  BuildContext context,
  T controller,
) {
  final b = builder;
  if (b != null) {
    return b(context, controller);
  }
  throw UnimplementedError(
    'LView: You must either provide a builder or override buildView in subclasses.',
  );
}