delete<S> static method

Future<bool> delete<S>({
  1. String? tag,
  2. bool force = false,
})

Removes the registration for S and disposes of the instance.

If the instance implements LevitScopeDisposable, its onClose method is called. If force is true, deletes even if the dependency was marked as permanent. Returns true if a registration was found and removed.

Implementation

static Future<bool> delete<S>({String? tag, bool force = false}) {
  return Ls.delete<S>(tag: tag, force: force);
}