findOrNull<S> static method
Finds an instance of type S, or returns null if missing.
Implementation
static S? findOrNull<S>({String? tag}) {
return Ls.findOrNull<S>(tag: tag);
}
Finds an instance of type S, or returns null if missing.
static S? findOrNull<S>({String? tag}) {
return Ls.findOrNull<S>(tag: tag);
}