onAppDetached method
void
onAppDetached()
Called when the flutter engine is detached from any host views.
Implementation
void onAppDetached() {}
Called when the flutter engine is detached from any host views.
void onAppDetached() {}