onAppInactive method
void
onAppInactive()
Called when the application is in an inactive state and not receiving input.
Implementation
void onAppInactive() {}
Called when the application is in an inactive state and not receiving input.
void onAppInactive() {}