onAppPaused method
void
onAppPaused()
Called when the application is not visible to the user and running in the background.
Implementation
void onAppPaused() {}
Called when the application is not visible to the user and running in the background.
void onAppPaused() {}