onAppResumed method
void
onAppResumed()
Called when the application is visible and responding to user input.
Implementation
void onAppResumed() {}
Called when the application is visible and responding to user input.
void onAppResumed() {}