find method

Future<T> find({
  1. String? tag,
})

Finds and resolves the store value in the active scope.

Throws if no active scope is available or initialization fails.

Implementation

Future<T> find({String? tag}) => findIn(Ls.currentScope, tag: tag);