findAsync method

Future<T> findAsync({
  1. String? tag,
})

Asynchronously finds and resolves the store value in the active scope.

Throws if no active scope is available or initialization fails.

Implementation

Future<T> findAsync({String? tag}) => findAsyncIn(Ls.currentScope, tag: tag);