LevitBuilderExtension<T> extension
Extensions for registering builder functions.
- on
-
- T Function()
Methods
-
levitLazyPut(
{String? tag, bool permanent = false, bool isFactory = false}) → void -
Available on T Function(), provided by the LevitBuilderExtension extension
Registers this builder for lazy instantiation in the active LevitScope. -
levitPut(
{String? tag, bool permanent = false}) → T -
Available on T Function(), provided by the LevitBuilderExtension extension
Registers the result of this builder in the active LevitScope.