levitLazyPut method
Registers this builder for lazy instantiation in the active LevitScope.
The builder will only be executed when the dependency is first requested.
If isFactory is true, the builder runs for every request.
Implementation
void levitLazyPut(
{String? tag, bool permanent = false, bool isFactory = false}) =>
Ls.lazyPut<T>(this, tag: tag, permanent: permanent, isFactory: isFactory);