levitPut method
Registers the result of this builder in the active LevitScope.
Use tag to distinguish between multiple instances of the same type.
Set permanent to true to persist across resets.
Returns the created instance.
Implementation
T levitPut({String? tag, bool permanent = false}) =>
Ls.put<T>(this, tag: tag, permanent: permanent);