LevitDisposable class abstract interface

A resource with an explicit, optionally asynchronous disposal operation.

Unlike LevitScopeDisposable, this contract has no initialization hooks. A directly registered instance implementing this interface is owned by its registration scope and disposed when that registration is removed.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() FutureOr<void>
Releases resources held by this object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited