restore property
A callback to restore the variable to this state.
Implementation
@override
void Function(dynamic value)? get restore => null;
A callback to restore the variable to this state.
@override
void Function(dynamic value)? get restore => null;