restore property
void Function(dynamic value)?
restore
final
A callback to restore the variable to this state.
Implementation
final void Function(dynamic value)? restore;
A callback to restore the variable to this state.
final void Function(dynamic value)? restore;