onSet property
LxOnSet?
get
onSet
Intercepts value mutations.
Return a wrapped function to modify or log the set operation.
Implementation
LxOnSet? get onSet => null;
Intercepts value mutations.
Return a wrapped function to modify or log the set operation.
LxOnSet? get onSet => null;