isBusy property
LxComputed<bool>
get
isBusy
Whether any latest logical execution is queued or running.
Implementation
LxComputed<bool> get isBusy {
_ensureReactiveTaskState();
return _isBusy!;
}
Whether any latest logical execution is queued or running.
LxComputed<bool> get isBusy {
_ensureReactiveTaskState();
return _isBusy!;
}