findAsync<S> abstract method

Future<S> findAsync<S>({
  1. String? tag,
})

Asynchronously finds an instance of type S in the current scope.

Uses optional tag to disambiguate registrations of the same type.

Throws if no matching registration is available.

Implementation

Future<S> findAsync<S>({String? tag});