findAsyncStore<R> abstract method

Future<R> findAsyncStore<R>(
  1. LevitAsyncStore<R> store, {
  2. String? tag,
})

Asynchronously finds and resolves the value of async store within the current scope.

Uses optional tag to select a store instance variant.

Throws if the store cannot be created or resolved.

Implementation

Future<R> findAsyncStore<R>(LevitAsyncStore<R> store, {String? tag});