findStore<R> abstract method

R findStore<R>(
  1. LevitStore<R> store, {
  2. String? tag,
})

Finds the value of store within the current scope.

Uses optional tag to select a store instance variant.

Throws if the store cannot be created or resolved.

Implementation

R findStore<R>(LevitStore<R> store, {String? tag});