lazyPutAsync<S> abstract method

Future<S> Function() lazyPutAsync<S>(
  1. Future<S> builder(), {
  2. String? tag,
  3. bool permanent = false,
  4. bool isFactory = false,
})

Lazily registers an asynchronous dependency using builder.

Returns a trigger function that starts resolution when invoked. If isFactory is true, builder runs on each resolution. If permanent is true, registration survives regular scope resets.

Implementation

Future<S> Function() lazyPutAsync<S>(Future<S> Function() builder,
    {String? tag, bool permanent = false, bool isFactory = false});