A lifecycle boundary that owns arbitrary cleanup resources.
- Implementers
Properties
-
disposed
→ Future<
void> -
Completes when cleanup reaches its terminal state.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether cleanup has completed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autoDispose<
T> (T resource) → T - Compatibility alias for own.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
own<
T> (T resource) → T -
Registers
resourcefor deterministic cleanup and returns it. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited