didAttachToScope method

void didAttachToScope(
  1. LevitScope scope, {
  2. String? key,
})
inherited

Called when the object is attached to a LevitScope.

This occurs after onInit. Use this callback if your initialization logic requires access to the scope itself or the registration key.

scope is the LevitScope that manages this object. key is the unique registration key associated with this instance.

Implementation

void didAttachToScope(LevitScope scope, {String? key}) {}