onClose method

FutureOr<void> onClose()

Called when the object is removed from the scope or the scope is disposed.

Use this method to release resources, close streams, or cancel timers.

Implementation

FutureOr<void> onClose() {}