find method

T find({
  1. String? tag,
})

Finds the value of this store in the active scope.

Uses optional tag to select an instance variant.

Throws if no active scope is available or value creation fails.

Implementation

T find({String? tag}) => findIn(Ls.currentScope, tag: tag);