LevitTaskCancelledException class

Thrown by LevitTaskContext.throwIfCancelled after cancellation.

Implemented types

Constructors

LevitTaskCancelledException(String taskId, String executionId)
Creates a cooperative cancellation exception.
const

Properties

executionId String
The unique execution ID.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskId String
The logical task ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited