LevitTaskContext class
Context passed to every task attempt.
Properties
- attempt → int
-
The one-based attempt number.
final
-
cancelled
→ Future<
void> -
Completes when cooperative cancellation is requested.
no setter
- executionId → String
-
A unique ID for this admitted execution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
Whether cooperative cancellation has been requested.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
The stable logical task ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reportProgress(
double value) → void -
Reports progress in the inclusive
0.0to1.0range. -
throwIfCancelled(
) → void - Throws LevitTaskCancelledException when cancellation was requested.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited