delete<S> static method

Future<bool> delete<S>({
  1. String? tag,
  2. bool force = false,
})

Removes a dependency from the active scope.

If force is true, permanent dependencies are also removed. Returns true if the dependency was found and removed.

Implementation

static Future<bool> delete<S>({String? tag, bool force = false}) {
  return currentScope.delete<S>(tag: tag, force: force);
}