find<S> static method

S find<S>({
  1. String? tag,
})

Finds a registered instance of type S in the active scope.

Throws an Exception if the dependency is not found.

Implementation

static S find<S>({String? tag}) {
  return currentScope.find<S>(tag: tag);
}