findOrNull<S> static method
Finds a registered instance of type S in the active scope, or null.
Implementation
static S? findOrNull<S>({String? tag}) {
return currentScope.findOrNull<S>(tag: tag);
}
Finds a registered instance of type S in the active scope, or null.
static S? findOrNull<S>({String? tag}) {
return currentScope.findOrNull<S>(tag: tag);
}