registeredCount property
int
get
registeredCount
The number of dependencies registered in the active scope.
Implementation
static int get registeredCount => currentScope.registeredCount;
The number of dependencies registered in the active scope.
static int get registeredCount => currentScope.registeredCount;