isSensitive property
Whether this reactive object contains sensitive data.
If true, the value will be obfuscated in monitor events and logs.
Implementation
@override
bool get isSensitive => _isSensitive;
Whether this reactive object contains sensitive data.
If true, the value will be obfuscated in monitor events and logs.
@override
bool get isSensitive => _isSensitive;