LxFamilyEviction class sealed
Cache eviction policy for LxFamily entries.
Constructors
- LxFamilyEviction.keepAlive()
-
Retains entries until explicit invalidation or family disposal.
constfactory
- LxFamilyEviction.whenInactive({Duration gracePeriod})
-
Evicts entries after they remain without listeners for
gracePeriod.constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited