emit method
Emits a new state.
This triggers a notification to all listeners if the state is different
from the current value.
Implementation
@protected
void emit(T state) => _setValueInternal(state);
Emits a new state.
This triggers a notification to all listeners if the state is different
from the current value.
@protected
void emit(T state) => _setValueInternal(state);