valueStream property
Stream<T>
get
valueStream
Returns the raw stream of values, unwrapped from LxStatus.
Implementation
Stream<T> get valueStream {
if (!_hasBoundSource) {
throw StateError('No source stream bound or stream has been closed.');
}
_valueController ??= StreamController<T>.broadcast(
onListen: () {
_checkActive();
_checkPendingBind();
},
onCancel: _checkActive,
);
_checkPendingBind();
return _valueController!.stream;
}