callback property
The callback to execute whenever the source notifies a change.
Implementation
final FutureOr<void> Function(T value) callback;
The callback to execute whenever the source notifies a change.
final FutureOr<void> Function(T value) callback;