TaskConflictException class
Describes a logical task conflict rejected by the engine.
- Implemented types
Constructors
- TaskConflictException(String taskId)
-
Creates a conflict exception for
taskId.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited