TaskDetails class

Represents the latest tracked execution of a logical task.

Constructors

TaskDetails({required LxStatus status, String? executionId, String ownerPath = '?', LevitTaskPhase phase = LevitTaskPhase.completed, LevitTaskMetadata metadata = LevitTaskMetadata.none, TaskPriority priority = TaskPriority.normal, int attempt = 0, LevitTaskOutcome? outcome, double weight = 1.0, double progress = 0.0, bool started = false, DateTime? queuedAt, DateTime? startedAt, DateTime? finishedAt, Duration? queueDuration, Duration? runDuration})
Creates task details.
const

Properties

attempt int
Current one-based attempt number.
final
executionId String?
Unique admitted execution ID, when known.
final
finishedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
metadata LevitTaskMetadata
Stable task metadata.
final
outcome LevitTaskOutcome?
Terminal outcome, when complete.
final
ownerPath String
Diagnostic path of the scheduling owner.
final
phase LevitTaskPhase
Current scheduling phase.
final
priority TaskPriority
Scheduling priority.
final
progress double
Progress from 0.0 to 1.0.
final
queuedAt DateTime?
final
queueDuration Duration?
final
runDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
started bool
Whether the task has started executing.
final
startedAt DateTime?
final
status LxStatus
The current reactive status of the task.
final
weight double
The weight used for aggregate progress.
final

Methods

copyWith({LxStatus? status, String? executionId, String? ownerPath, LevitTaskPhase? phase, LevitTaskMetadata? metadata, TaskPriority? priority, int? attempt, LevitTaskOutcome? outcome, double? weight, double? progress, bool? started, DateTime? queuedAt, DateTime? startedAt, DateTime? finishedAt, Duration? queueDuration, Duration? runDuration}) TaskDetails
Creates a copy with selected fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited