LRouteScope class
A route-aware wrapper around LScope.
LRouteScope keeps the underlying dependency scope widget-tree-bound, but
also binds that scope to the current ModalRoute. When the route identity
changes, the local scope is recreated. Descendants can observe the current
route visibility through visibilityOf.
This is useful when route lifetime, not just subtree lifetime, is the meaningful ownership boundary.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LRouteScope
Constructors
-
LRouteScope({Key? key, LScopeDependencyFactory? dependencyFactory, required Widget child, String? name, List<
Object?> ? args}) -
Creates a route-bound dependency scope.
const
Properties
-
args
→ List<
Object?> ? -
Optional dependency keys for reactive re-initialization.
final
- child → Widget
-
The widget subtree that will have access to this scope.
final
- dependencyFactory → LScopeDependencyFactory?
-
An optional factory to register dependencies in this scope.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- name → String?
-
A descriptive name for the scope.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lazyPut<
S> (S builder(), {Key? key, required Widget child, String? name, String? tag, bool permanent = false, bool isFactory = false, List< Object?> ? args}) → LRouteScope - A shorthand for creating a route-bound scope and registering a lazy dependency.
-
lazyPutAsync<
S> (Future< S> builder(), {Key? key, required Widget child, String? name, String? tag, bool permanent = false, bool isFactory = false, List<Object?> ? args}) → LRouteScope - A shorthand for creating a route-bound scope and registering an async lazy dependency.
-
put<
S> (S builder(), {Key? key, required Widget child, String? name, String? tag, bool permanent = false, List< Object?> ? args}) → LRouteScope - A shorthand for creating a route-bound scope and immediately registering a dependency.
-
routeOf(
BuildContext context, {bool listen = false}) → ModalRoute? - The ModalRoute currently bound to the nearest LRouteScope.
-
visibilityOf(
BuildContext context, {bool listen = false}) → LxReactive< LRouteVisibility> ? - Reactive visibility for the nearest LRouteScope.
-
visibilityValueOf(
BuildContext context, {bool listen = false}) → LRouteVisibility - Snapshot visibility for the nearest LRouteScope.