LRouteVisibility enum

Visibility state for the route bound to an LRouteScope.

Inheritance
Available extensions

Values

inactive → const LRouteVisibility

No active route is currently bound to the scope.

current → const LRouteVisibility

The bound route is the current visible route.

covered → const LRouteVisibility

The bound route is still active but currently covered by another route.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LRouteVisibility>
A constant List of the values in this enum, in order of their declaration.