LevitAsyncStore<T> class
A specialized store for asynchronous initialization.
Unlike LevitStore<Future<T>>, this type provides ergonomic lookup methods
that always resolve to Future<T> (single await).
Constructors
-
LevitAsyncStore(Future<
T> builder(LevitRef ref)) -
Creates an asynchronous store definition from
builder.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
{String? tag, bool force = false}) → Future< bool> - Removes this store from the active scope.
-
deleteIn(
LevitScope scope, {String? tag, bool force = false}) → Future< bool> -
Deletes the store instance from
scope. -
find(
{String? tag}) → Future< T> - Finds and resolves the store value in the active scope.
-
findAsync(
{String? tag}) → Future< T> - Asynchronously finds and resolves the store value in the active scope.
-
findAsyncIn(
LevitScope scope, {String? tag}) → Future< T> -
Asynchronously finds or creates and resolves the store value within
scope. -
findIn(
LevitScope scope, {String? tag}) → Future< T> -
Finds or creates and resolves the store value within
scope. -
isInstantiatedIn(
LevitScope scope, {String? tag}) → bool -
Checks if the store is instantiated in
scope. -
isRegisteredIn(
LevitScope scope, {String? tag}) → bool -
Checks if the store is registered in
scope. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited