Asynchronously finds and resolves the store value in the active scope.
Throws if no active scope is available or initialization fails.
Future<T> findAsync({String? tag}) => findAsyncIn(Ls.currentScope, tag: tag);