LevitDisposalException class final
Aggregate error thrown after best-effort disposal has finished.
Cleanup always continues after an individual failure. Callers receive this exception only after every selected resource has been given a chance to close.
- Implemented types
Constructors
-
LevitDisposalException(Iterable<
LevitDisposalFailure> failures) - Creates an aggregate disposal error.
Properties
-
failures
→ List<
LevitDisposalFailure> -
All failures in deterministic disposal order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited