LevitDisposalFailure class final
One failure captured while a scope or resource owner was being disposed.
Constructors
- LevitDisposalFailure({required Object resource, required Object error, required StackTrace stackTrace})
-
Creates a disposal failure record.
const
Properties
- error → Object
-
The error thrown by the resource.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resource → Object
-
The resource whose cleanup failed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
The associated stack trace.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited