findStoreAsync<R> abstract method
Asynchronously finds the value of store within the current scope.
Uses optional tag to select a store instance variant.
Throws if the store cannot be created or resolved.
Implementation
Future<R> findStoreAsync<R>(LevitStore<R> store, {String? tag});