LevitScopeKey class
Typed key for dependency registrations.
This avoids relying on Type.toString() (or S.toString()) for identity,
which can change under obfuscation/minification. String representations are
kept for debugging/middleware only.
Constructors
- LevitScopeKey(Type type, String? tag)
-
const
Properties
- debugString → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
- type → Type
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
of<
S> ({String? tag}) → LevitScopeKey