findAsync method
Asynchronously finds the value of this store in the active scope.
Uses optional tag to select an instance variant.
Throws if no active scope is available or value creation fails.
Implementation
Future<T> findAsync({String? tag}) => findAsyncIn(Ls.currentScope, tag: tag);