LevitTaskEvent class
Structured lifecycle event emitted by LevitTaskEngine.
Constructors
- LevitTaskEvent({required LevitTaskEventType type, required String taskId, String? executionId, String ownerPath = '?', LevitTaskPhase? phase, LevitTaskMetadata? metadata, TaskPriority priority = TaskPriority.normal, int attempt = 0, int maxRetries = 0, DateTime? queuedAt, DateTime? startedAt, DateTime? finishedAt, Duration? queueDuration, Duration? runDuration, Duration? retryIn, double? progress, TaskSkipReason? skipReason, LevitTaskOutcome? outcome, Object? error, StackTrace? stackTrace, bool? runsInIsolate, bool? runInIsolate, String? debugName, DateTime? timestamp})
Properties
- attempt → int
-
final
- debugName → String?
-
Compatibility view of LevitTaskMetadata.debugName.
no setter
- error → Object?
-
final
- executionId → String
-
Unique admitted execution ID.
final
- finishedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
final
- metadata → LevitTaskMetadata
-
final
- outcome → LevitTaskOutcome?
-
final
- ownerPath → String
-
Diagnostic path of the owner that scheduled the execution.
final
- phase → LevitTaskPhase
-
final
- priority → TaskPriority
-
final
- progress → double?
-
final
- queuedAt → DateTime
-
final
- queueDuration → Duration?
-
final
- retryIn → Duration?
-
final
- runDuration → Duration?
-
final
- runInIsolate → bool
-
Compatibility alias for runsInIsolate.
no setter
- runsInIsolate → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipReason → TaskSkipReason?
-
final
- stackTrace → StackTrace?
-
final
- startedAt → DateTime?
-
final
- taskId → String
-
Stable logical task ID.
final
- timestamp → DateTime
-
final
- type → LevitTaskEventType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited