LevitTaskExecution<T> class
A lightweight handle for one scheduled or joined execution.
Properties
- disposition → LevitTaskSubmissionDisposition
-
How this submission was handled.
final
- executionId → String
-
Unique admitted execution ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
result
→ Future<
T?> -
The eventual result. Cancellation, dropping, and superseding yield
null.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
Stable logical task ID.
final
Methods
-
cancel(
) → void - Cooperatively cancels this execution.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited