LevitTaskExecutionSummary class
A dependency-free summary retained by LevitTaskTracker.
Constructors
- LevitTaskExecutionSummary({required String taskId, required String executionId, required String ownerPath, required LevitTaskPhase phase, required LevitTaskMetadata metadata, required TaskPriority priority, required int attempt, required DateTime queuedAt, DateTime? startedAt, DateTime? finishedAt, Duration? queueDuration, Duration? runDuration, double progress = 0, LevitTaskOutcome? outcome, Object? error, StackTrace? stackTrace})
-
const
- LevitTaskExecutionSummary.fromEvent(LevitTaskEvent event)
-
factory
Properties
- attempt → int
-
final
- error → Object?
-
final
- executionId → String
-
final
- finishedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → LevitTaskMetadata
-
final
- outcome → LevitTaskOutcome?
-
final
- ownerPath → String
-
final
- phase → LevitTaskPhase
-
final
- priority → TaskPriority
-
final
- progress → double
-
final
- queuedAt → DateTime
-
final
- queueDuration → Duration?
-
final
- runDuration → Duration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
- startedAt → DateTime?
-
final
- taskId → String
-
final
Methods
-
apply(
LevitTaskEvent event) → LevitTaskExecutionSummary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited