LevitTaskMiddleware class abstract
Receives task events from every LevitTaskEngine in this isolate.
Constructors
- LevitTaskMiddleware()
-
Creates a task middleware.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTaskEvent(
LevitTaskEvent event) → void - Handles one structured task event.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
add<
T extends LevitTaskMiddleware> (T middleware, {Object? token}) → T -
Registers
middlewareglobally, optionally replacing the sametoken. -
contains(
LevitTaskMiddleware middleware) → bool -
Whether
middlewareis registered. -
remove(
LevitTaskMiddleware middleware) → bool -
Removes
middlewareand any tokens attached to it. -
removeByToken(
Object token) → bool -
Removes the middleware registered for
token.