delete<S> static method
Removes a dependency from the active scope.
If force is true, permanent dependencies are also removed.
Returns true if the dependency was found and removed.
Implementation
static Future<bool> delete<S>({String? tag, bool force = false}) {
return currentScope.delete<S>(tag: tag, force: force);
}