findAsync<S> static method
Asynchronously finds a registered instance of type S in the active scope.
Throws an Exception if the dependency is not found.
Implementation
static Future<S> findAsync<S>({String? tag}) {
return currentScope.findAsync<S>(tag: tag);
}